
# Slot: affects stability of


holds between two molecular entities where the action or effect of one impacts the stability of the other within a system of interest

URI: [biolink:affects_stability_of](https://w3id.org/biolink/vocab/affects_stability_of)


## Domain and Range

[MolecularEntity](MolecularEntity.md) &#8594;  <sub>0..\*</sub> [MolecularEntity](MolecularEntity.md)

## Parents

 *  is_a: [affects](affects.md)

## Children

 *  [decreases stability of](decreases_stability_of.md)
 *  [increases stability of](increases_stability_of.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | CTD:affects_stability_of |
| **Close Mappings:** | | GAMMA:stabilization |

